#!/usr/bin/env python
# -*- coding: UTF8 -*-

import sys, codecs, os

from xml.etree import ElementTree as ET

def getDT(dt):
    assert dt[10] == "T" and dt[23] == "Z"
    return dt[:10] + " " + dt[11:19]

def getQuien(mess):
    assert mess.tag == "From"
    quien = mess[0].attrib["FriendlyName"]
    return quien

def getTexto(mess):
    assert mess.tag == "Text"
    texto = mess.text
    return texto

def main(nomarch):
    if nomarch[-4:].lower() != ".xml":
        raise ValueError("El archivo no tiene extensión .xml")
    dirdest = nomarch[:-4]
    os.mkdir(dirdest)

    tree = ET.parse(nomarch)
    root = tree.getroot()

    sesion_ant = None
    salida = None
    for mess in root:
        dt = getDT(mess.attrib['DateTime'])
        sesion = mess.attrib['SessionID']
        if sesion != sesion_ant:
            sesion_ant = sesion
            p1,p2 = dt.split(" ")
            nomarch = "%s.%s.txt" % (p1, "".join(p2.split(":")))
            salida = codecs.open(os.path.join(dirdest, nomarch), "w", "utf8")

        if mess.tag == "Message":
            quien = getQuien(mess[0])
            texto = getTexto(mess[2])
            linea = "%s - %s: %s\n" % (dt, quien, texto)

        elif mess.tag in ("Join", "Leave"):
            texto = getTexto(mess[1])
            linea = "%s - *** %s\n" % (dt, texto)
            
        elif mess.tag in ("Invitation", "InvitationResponse"):
            texto = getTexto(mess[2])
            linea = "%s - *** %s\n" % (dt, texto)
            
        else:
            raise ValueError("Tipo de mensaje desconocido: %r" % mess.tag)

        salida.write(linea)


if __name__ == "__main__":
    if len(sys.argv) != 2:
        print "Usar: msnxml2dir.py <arch.xml>"
        sys.exit()

    main(sys.argv[1])
